@@ -23,10 +23,17 @@ sub new {
     my ( $class, $opt ) = @_;
     $opt->{db_driver} = 'SQLite';
     $opt->{driver_prefix} = 'sqlite';
+    $opt->{plugin_api_version} = 1.0;
     bless $opt, $class;
 }
 
 
+sub plugin_api_version {
+    my ( $self ) = @_;
+    return $self->{plugin_api_version};
+}
+
+
 sub db_driver {
     my ( $self ) = @_;
     return $self->{db_driver};
